(function($){
    $(function () {

        /* Initialize start date and end date */
        initializeDateSelectors();
        function initializeDateSelectors() {
            if($('#start-date').length > 0) {
                $('#start-date').datePicker({'overrideBrowserDefault': true, onSelect: changeDay});
                $('#end-date').datePicker({'overrideBrowserDefault': true, onSelect: changeDay});
            }

            var currentDate = new Date();
            var startDate = addDays(currentDate, -30);
            var startDateValue = (new Date(startDate - startDate.getTimezoneOffset() * 60000)).toISOString().slice(0, 10);
            var endDate = currentDate;
            var endDateValue = (new Date(endDate - endDate.getTimezoneOffset() * 60000)).toISOString().slice(0, 10);

            var queryStartDate = getQueryStringValue("startDate");
            var queryEndDate = getQueryStringValue("endDate");

            if(queryStartDate !== ""){
                startDateValue = queryStartDate;
            }
            if(queryEndDate !== ""){
                endDateValue = queryEndDate;
            }

            $("#start-date").val(startDateValue);
            $("#end-date").val(endDateValue);

            loadAttachmentViews();
        }

        $("#selected-date-dropdown a").on("click", function (e) {
            e.preventDefault();

            var text = $(this).text();
            $("#selected-date").text(text);

            var currentDate = new Date();
            var startDate = currentDate;
            var endDate = currentDate;

            if(text === "Past 30 days"){
                startDate = addDays(startDate, -30);

            }else if(text === "Past 90 days"){
                startDate = addDays(startDate, -90);

            }else if(text === "This month"){
                startDate = new Date(startDate.getFullYear(), startDate.getMonth(), 1);

            }else if(text === "Last month"){
                startDate = new Date(startDate.getFullYear(), startDate.getMonth()- 1, 1);
                endDate = new Date(endDate.getFullYear(), endDate.getMonth(), 0);

            }else if(text === "All dates"){
                $("#start-date").val("");
                $("#end-date").val("");
            }

            if(text !== "Custom"){
                if(text !== "All dates") {
                    var startDateValue = (new Date(startDate - startDate.getTimezoneOffset() * 60000)).toISOString().slice(0, 10);
                    var endDateValue = (new Date(endDate - endDate.getTimezoneOffset() * 60000)).toISOString().slice(0, 10);

                    $("#start-date").val(startDateValue);
                    $("#end-date").val(endDateValue);
                }


                loadAttachmentViews();
            }
        });

        function addDays(date, days) {
            var result = new Date(date);
            result.setDate(result.getDate() + days);
            return result;
        }

        function changeDay() {
            $("#selected-date").text("Custom");
            loadAttachmentViews();
        }

        function getQueryStringValue(queryString){

            var params = decodeURI(window.location.search)
                            .replace('?', '')
                            .split('&');

            for(var i = 0; i < params.length; i ++){
                var paramArr = params[i].split('=');
                if(paramArr[0].toLowerCase() === queryString.toLowerCase()){
                    if(paramArr[1] === undefined){
                        return "";
                    }
                    return paramArr[1];
                }
            }

            return "";
        }

        function loadAttachmentViews() {

            var loadingImgEl = $("#attachment-loading img").show();
            var pageId = $("#page-id").val();
            var attachmentId = $("#attachment-id").val();
            var pageSize = 50;
            var pageIndex = 1;
            var start = $("#start-date").val();
            start = start === "" ? "" : new Date(start).toISOString().slice(0,10);

            var end = $("#end-date").val();
            end = end === "" ? "" : new Date(end).toISOString().slice(0,10);

            $.ajax({
                cache: false,
                data: {
                    pageId: pageId,
                    pageIndex : pageIndex,
                    pageSize: pageSize,
                    startDate: start,
                    endDate: end,
                    attachmentId: attachmentId
                },
                dataType: "json",
                error: function (XMLHttpRequest, textStatus, errorThrown) {
                    if (XMLHttpRequest.status === 401) {
                        location.reload();
                    }
                    loadingImgEl.hide();
                },
                success: function (data) {
                    var attachmentViewDetail = Elisoft.Confluence.PageView.Templates.attachmentViewers({
                        data: data
                    });

                    $("#data-view").html(attachmentViewDetail);

                    try{
                        AJS.Confluence.Binder.userHover();
                    }catch (err)
                    {}

                    loadingImgEl.hide();
                },
                type: "GET",
                timeout: PageTrackingUtils.ajaxTimeout,
                url: PageTrackingUtils.getPageUtilityServiceBaseUrl("/attachment-viewers")
            });
        }

    });
}(AJS.$));