(function($){
    $(function () {

        loadPageViewCount();
        function loadPageViewCount(){

            var pageId = $("#page-id").val();
            if(pageId === undefined || pageId == "" || pageId == 0)
            {
                window.location.href = AJS.contextPath() + "/";
            }

            $.ajax({
                cache: false,
                data: {pageId: pageId,
                    excludeCount : true
                },
                dataType: "json",
                error: function (XMLHttpRequest, textStatus, errorThrown) {
                    window.location.href = AJS.contextPath() + "/";
                },
                success: function (data) {
                    var showPageView = data.spv;
                    var showPageViewDetail = showPageView && data.spvd;
                    if(showPageViewDetail == false){
                        return;
                    }

                    var hasViewPermission = data.hvp;
                    var isSpaceAdmin = data.sa;
                    var showMap = data.sm;

                    if(isSpaceAdmin || hasViewPermission){
                        $("#page-view-disable-tracking").removeClass("hidden");

                        if(showMap){
                            $("#page-view-map").removeClass("hidden");
                        }
                    }
                },
                type: "GET",
                timeout: PageTrackingUtils.ajaxTimeout,
                url: PageTrackingUtils.getPageUtilityServiceBaseUrl("/page-view-count")
            });
        }


        /* CHART VIEW */
        /* Initialize start date and end date */
        initializeDateSelectors();
        function initializeDateSelectors() {
            if($('#start-date').length > 0) {
                $('#start-date').datePicker({'overrideBrowserDefault': true, onSelect: changeDay});
                $('#end-date').datePicker({'overrideBrowserDefault': true, onSelect: changeDay});
            }

            var currentDate = new Date();
            var startDate = addDays(currentDate, -30);
            var startDateValue = (new Date(startDate - startDate.getTimezoneOffset() * 60000)).toISOString().slice(0, 10);
            var endDate = currentDate;
            var endDateValue = (new Date(endDate - endDate.getTimezoneOffset() * 60000)).toISOString().slice(0, 10);

            $("#start-date").val(startDateValue);
            $("#end-date").val(endDateValue);
        }

        $("#selected-date-dropdown a").on("click", function (e) {
            e.preventDefault();

            var text = $(this).text();
            $("#selected-date").text(text);

            var currentDate = new Date();
            var startDate = currentDate;
            var endDate = currentDate;

            if(text === "Past 30 days"){
                startDate = addDays(startDate, -30);

            }else if(text === "Past 90 days"){
                startDate = addDays(startDate, -90);

            }else if(text === "This month"){
                startDate = new Date(startDate.getFullYear(), startDate.getMonth(), 1);

            }else if(text === "Last month"){
                startDate = new Date(startDate.getFullYear(), startDate.getMonth()- 1, 1);
                endDate = new Date(endDate.getFullYear(), endDate.getMonth(), 0);

            }else if(text === "All dates"){
                $("#start-date").val("");
                $("#end-date").val("");
            }

            if(text !== "Custom"){
                if(text !== "All dates") {
                    var startDateValue = (new Date(startDate - startDate.getTimezoneOffset() * 60000)).toISOString().slice(0, 10);
                    var endDateValue = (new Date(endDate - endDate.getTimezoneOffset() * 60000)).toISOString().slice(0, 10);

                    $("#start-date").val(startDateValue);
                    $("#end-date").val(endDateValue);
                }

                showChart();
                loadAttachmentViews();
                loadPageViewUsers();
            }
        });

        function addDays(date, days) {
            var result = new Date(date);
            result.setDate(result.getDate() + days);
            return result;
        }

        function changeDay() {
            $("#selected-date").text("Custom");
            showChart();
            loadAttachmentViews();
            loadPageViewUsers();
        }

        showChart();
        function showChart() {

            var pageId = $('#page-id').val();

            var start = $("#start-date").val();
            start = start === "" ? "" : new Date(start).toISOString().slice(0,10);

            var end = $("#end-date").val();
            end = end === "" ? "" : new Date(end).toISOString().slice(0,10);

            $.ajax({
                cache: false,
                data: {
                    startDate: start,
                    endDate: end,
                    pageId: pageId
                },
                dataType: "json",
                error: function (XMLHttpRequest, textStatus, errorThrown) {
                    $("#trend-chart #chart").html("Error rendering chart.");
                },
                success: function (data) {
                    try {
                        if (data.status === true) {

                            var showPoint = false;
                            if(data.result !== undefined && data.result.length === 1){
                                showPoint = true;
                            }

                            var keys = {
                                x: 'date',
                                value: ["comments", "views"]
                            };

                            var names = {
                                comments: "Comments", views: "Views"
                            };

                            var chart = c3.generate({
                                padding: {
                                    right: 20
                                },
                                bindto: '#trend-chart #chart',
                                data: {
                                    x: 'date',
                                    xFormat: '%Y-%m-%d',
                                    json: data.result,
                                    keys: keys,
                                    names: names,
                                    colors: {
                                        comments: '#ff7f0e',
                                        views: '#2ca02c'
                                    }
                                },
                                axis: {
                                    x: {
                                        type: 'timeseries',
                                        tick: {
                                            format: "%b %e, %y"
                                        }
                                    },
                                    y:{
                                        min : 0,
                                        padding: {top: 100, bottom: 0}
                                    }
                                },
                                point: {
                                    show: showPoint
                                }
                            });
                        }
                        else {
                            $("#trend-chart #chart").html("Error rendering chart.");
                        }
                    }catch (err){
                        $("#trend-chart #chart").html("Error rendering chart.");
                    }
                },
                type: "GET",
                timeout: PageTrackingUtils.ajaxTimeout,
                url: PageTrackingUtils.getPageUtilityServiceBaseUrl("/page-chart-statistics")
            });
        }

        loadPageViewUsers();
        function loadPageViewUsers(currentPage) {

            if(currentPage === undefined){
                currentPage = 1;
            }

            var pageId = $("#page-id").val();
            var pageSize = 50;

            var start = $("#start-date").val();
            start = start === "" ? "" : new Date(start).toISOString().slice(0,10);

            var end = $("#end-date").val();
            end = end === "" ? "" : new Date(end).toISOString().slice(0,10);

            $.ajax({
                cache: false,
                data: {
                    pageId: pageId,
                    pageIndex : currentPage,
                    pageSize: pageSize,
                    startDate: start,
                    endDate: end
                },
                dataType: "json",
                error: function (XMLHttpRequest, textStatus, errorThrown) {
                    if (XMLHttpRequest.status === 401) {
                        window.location.href = AJS.contextPath() + "/";
                    }
                    $("#page-loading img").hide();
                },
                success: function (data) {
                    var pageViewDetail = Elisoft.Confluence.PageView.Templates.pageViewDetail({
                        data: data
                    });

                    $("#data-view-data").html(pageViewDetail);//.fadeIn("slow");

                    var pagination = Elisoft.Confluence.PageView.Templates.pagination({
                        currentPage: currentPage, totalPages: data.totalPages
                    });

                    $("#data-view-paging").html(pagination);

                    try{
                        AJS.Confluence.Binder.userHover();
                    }catch (err)
                    {}

                    $("#page-loading img").hide();
                },
                type: "GET",
                timeout: PageTrackingUtils.ajaxTimeout,
                url: PageTrackingUtils.getPageUtilityServiceBaseUrl("/page-view")
            });
        }

        var dataViewPagination = $("#data-view-paging");
        dataViewPagination.on("click", "a", function(e) {
            e.preventDefault();
            $("#page-loading img").show();

            var currentPage = parseInt($(this).attr("data-page"));
            loadPageViewUsers(currentPage);
        });

        // Enable or disable page tracking on this page
        $("body").on("click", "#page-view-disable-tracking", function(event){
            event.preventDefault();

            var pageId = $("#page-id").val();
            if(pageId === undefined){
                return;
            }

            var status = false;

            if($(this).hasClass("enable")){

                if(confirm("Are you sure you want to disable page view tracking for this page?")){
                    $(this).removeClass("enable").addClass("disable").html("Enable Tracking");
                    $(this).attr("title", "Enable Tracking Page Views");
                    $("#page-content").hide();
                    status = false;
                }
                else {
                    return;
                }
            }
            else {
                $(this).removeClass("disable").addClass("enable").html("Disable Tracking");
                $(this).attr("title", "Disable Tracking Page Views");
                $("#page-content").show();
                status = true;
            }

            $.ajax({
                cache: false,
                data: {pageId: pageId, status : status},
                dataType: "json",
                type: "PUT",
                error: function(jqXHR, textStatus, errorThrown) {
                    console.log("ERROR: " + pageId)
                },
                success: function(data) {
                    if(data.status){
                        console.log(pageId);
                    }
                },
                timeout: PageTrackingUtils.ajaxTimeout,
                url: PageTrackingUtils.getPageUtilityServiceBaseUrl("/update-tracking-status")
            });
        });

        function loadAttachmentViews() {

            var loadingImgEl = $("#attachment-loading img").show();

            var pageId = $("#page-id").val();
            var pageSize = 50;
            var pageIndex = 1;
            var start = $("#start-date").val();
            start = start === "" ? "" : new Date(start).toISOString().slice(0,10);

            var end = $("#end-date").val();
            end = end === "" ? "" : new Date(end).toISOString().slice(0,10);


            $.ajax({
                cache: false,
                data: {
                    pageId: pageId,
                    pageIndex : pageIndex,
                    pageSize: pageSize,
                    startDate: start,
                    endDate: end,
                },
                dataType: "json",
                error: function (XMLHttpRequest, textStatus, errorThrown) {
                    if (XMLHttpRequest.status === 401) {
                        window.location.href = AJS.contextPath() + "/";
                    }
                    loadingImgEl.hide();
                },
                success: function (data) {
                    var attachmentViewDetail = Elisoft.Confluence.PageView.Templates.attachmentViewDetail({
                        data: data
                    });

                    $("#attachment-view").html(attachmentViewDetail);

                    try{
                        AJS.Confluence.Binder.userHover();
                    }catch (err)
                    {}

                    loadingImgEl.hide();
                },
                type: "GET",
                timeout: PageTrackingUtils.ajaxTimeout,
                url: PageTrackingUtils.getPageUtilityServiceBaseUrl("/page-attachments")
            });
        }

        $("#tab-attachment").click(function (event) {

            if($("#page-attachment-table").length > 0){
                return;
            }

            loadAttachmentViews();
        });

    });
}(AJS.$));