(function($){
    $(function () {

        /* Initialize start date and end date */
        initializeDateSelectors();
        function initializeDateSelectors() {
            if($('#start-date').length > 0) {
                $('#start-date').datePicker({'overrideBrowserDefault': true, onSelect: changeDay});
                $('#end-date').datePicker({'overrideBrowserDefault': true, onSelect: changeDay});
            }

            var currentDate = new Date();
            var startDate = addDays(currentDate, -30);
            var startDateValue = (new Date(startDate - startDate.getTimezoneOffset() * 60000)).toISOString().slice(0, 10);
            var endDate = currentDate;
            var endDateValue = (new Date(endDate - endDate.getTimezoneOffset() * 60000)).toISOString().slice(0, 10);

            $("#start-date").val(startDateValue);
            $("#end-date").val(endDateValue);
        }

        function addDays(date, days) {
            var result = new Date(date);
            result.setDate(result.getDate() + days);
            return result;
        }

        /* PAGE VIEW */
        function getPageViewSearchData() {
            var start = $("#start-date").val();
            start = start === "" ? "" : new Date(start).toISOString().slice(0, 10);

            var end = $("#end-date").val();
            end = end === "" ? "" : new Date(end).toISOString().slice(0, 10);

            var pageName = $("#page-stats-page").val();
            var spaceKey = AJS.Meta.get("space-key");

            // Get sorKey and sortOrder
            var sortKey = "";
            var sortOrder = "";
            var sortItemElement = $("span.fa.fa-sort-desc", pageTrackingTableHead);
            if(sortItemElement.length > 0){
                sortOrder = "desc";
                sortKey = sortItemElement.attr("data-sort-key");
            }else {
                sortItemElement = $("span.fa.fa-sort-asc", pageTrackingTableHead);
                if (sortItemElement.length > 0) {
                    sortOrder = "asc";
                    sortKey = sortItemElement.attr("data-sort-key");
                }
            }

            return {
                startDate: start,
                endDate: end,
                sortKey: sortKey,
                sortOrder: sortOrder,
                keyword: pageName,
                spaceKey: spaceKey
            }
        }

        loadPageViewAll();
        function loadPageViewAll(currentPage){
            if(currentPage == null || currentPage == undefined){
                currentPage = 1;
            }

            try {
                // show loading icon
                $("#page-loading img").show();

                var requestData = getPageViewSearchData();
                $.extend(requestData, {
                    pageIndex : currentPage,
                    pageSize: 50,
                    loadAll: true
                });

                $("#page-view-export-link").attr("href", Confluence.getContextPath() +
                    "/rest/page-tracking-services/1.0/page-tracking/page-statistics.xlsx?startDate=" + requestData.startDate +
                    "&endDate=" + requestData.endDate + "&keyword=" + requestData.keyword + "&spaceKey=" + requestData.spaceKey +
                    "&loadAll=true");

                $.ajax({
                    data: requestData,
                    cache: false,
                    dataType: "json",
                    error: function (XMLHttpRequest, textStatus, errorThrown) {
                        $("#page-loading img").hide();

                        if(XMLHttpRequest.status === 401) {
                            var redirectUrl = AJS.contextPath() + "/login.action?os_destination=" +
                                encodeURIComponent(window.location.href) + "&permissionViolation=true";
                            window.location.href = redirectUrl;
                        }

                    },
                    success: function (data) {
                        var result = "";
                        if (data.status === true) {
                            result = Elisoft.Confluence.PageView.Templates.pageView({ data: data });
                        }

                        $("#data-view-data #page-tracking-results table tbody").html(result);
                        $("#page-loading img").hide();

                        var pagination = Elisoft.Confluence.PageView.Templates.pagination({
                            currentPage: currentPage,
                            totalPages: data.totalPages
                        });

                        $("#data-view-paging").html(pagination);

                    },
                    type: "GET",
                    timeout: PageTrackingUtils.ajaxTimeout,
                    url: PageTrackingUtils.getPageUtilityServiceBaseUrl("/page-view-all")
                });
            }catch (err){

            }
        }

        var dataViewPagination = $("#data-view-paging");
        dataViewPagination.on("click", "a", function(e) {
            e.preventDefault();
            $("#page-loading img").show();
            $("#pagination-loading-icon").show();

            var currentPage = parseInt($(this).attr("data-page"));
            loadPageViewAll(currentPage);
        });

        //SORT
        var pageTrackingTableHead = $("#data-view-data #page-tracking-results table thead");
        pageTrackingTableHead.on("click", "th", function(e) {
            e.preventDefault();

            var sortIcon = $("span.fa", this);
            if(sortIcon.length > 0){
                var classToAdd = "";
                if(!sortIcon.hasClass("fa-sort-asc") && !sortIcon.hasClass("fa-sort-desc")){
                    if(sortIcon.hasClass("down")){
                        classToAdd = "fa-sort-desc";
                    }
                    else {
                        classToAdd = "fa-sort-asc";
                    }
                }
                else if(sortIcon.hasClass("fa-sort-asc")){
                    sortIcon.addClass("down");
                    sortIcon.removeClass("fa-sort-asc")
                }
                else if(sortIcon.hasClass("fa-sort-desc")){
                    sortIcon.removeClass("down");
                    sortIcon.removeClass("fa-sort-desc");
                }

                $("th span.fa", pageTrackingTableHead).removeClass("fa-sort-desc").removeClass("fa-sort-asc");

                if(classToAdd != ""){
                    sortIcon.addClass(classToAdd);
                }

                var currentPage = parseInt($(".aui-nav-selected", dataViewPagination).text());
                if(isNaN(currentPage)){
                    currentPage = 1;
                }

                loadPageViewAll(currentPage);
            }
        });

        // SEARCH
        $("#page-stats-search").on("click", function (e) {
            e.preventDefault();
            loadPageViewAll();
        });

        $("#page-stats-page").keypress(function(e){
            var key = e.which;
            if(key === 13){
                loadPageViewAll();
            }
        });

        $("#page-stats-clear").on("click", function (e) {
            e.preventDefault();

            $("#page-stats-page").val("");
            $("#page-stats-space").val("");

            loadPageViewAll();
        });

        var pageTrackingResults = $("#page-tracking-results");
        var $deletePageViewDialog = $("#delete-page-view-dialog");
        // delete page view
        pageTrackingResults.on("click", ".delete-page-view", function(e) {
            e.preventDefault();

            AJS.dialog2($deletePageViewDialog).show();
            $("#page-view-page-id", $deletePageViewDialog).val($(this).attr("data"));
        });

        // Save
        $deletePageViewDialog.on("click", ".ok-button", function(event){
            event.preventDefault();

            var pageId = $("#page-view-page-id", $deletePageViewDialog).val();

            $.ajax({
                cache: false,
                data: {
                    pageId: pageId
                },
                dataType: "json",
                type: "PUT",
                error: function(jqXHR, textStatus, errorThrown) {

                    window.location.reload();
                },
                success: function(data) {
                    loadPageViewAll();
                    showChart();
                    loadUserStatisticsWhenActive();

                    AJS.dialog2($deletePageViewDialog).hide();
                },
                timeout: PageTrackingUtils.ajaxTimeout,
                url: PageTrackingUtils.getPageUtilityServiceBaseUrl("/clear-page-view")
            });

        });

        // Cancel
        $deletePageViewDialog.on("click", ".cancel-button", function(event){
            event.preventDefault();

            AJS.dialog2($deletePageViewDialog).hide();
        });



        /* CHART VIEW */

        $("#selected-date-dropdown a").on("click", function (e) {
            e.preventDefault();

            var text = $(this).text();
            $("#selected-date").text(text);

            var currentDate = new Date();
            var startDate = currentDate;
            var endDate = currentDate;

            if(text === "Past 30 days"){
                startDate = addDays(startDate, -30);

            }else if(text === "Past 90 days"){
                startDate = addDays(startDate, -90);

            }else if(text === "This month"){
                startDate = new Date(startDate.getFullYear(), startDate.getMonth(), 1);

            }else if(text === "Last month"){
                startDate = new Date(startDate.getFullYear(), startDate.getMonth()- 1, 1);
                endDate = new Date(endDate.getFullYear(), endDate.getMonth(), 0);

            }else if(text === "All dates"){
                $("#start-date").val("");
                $("#end-date").val("");
            }

            if(text !== "Custom"){
                if(text !== "All dates") {
                    var startDateValue = (new Date(startDate - startDate.getTimezoneOffset() * 60000)).toISOString().slice(0, 10);
                    var endDateValue = (new Date(endDate - endDate.getTimezoneOffset() * 60000)).toISOString().slice(0, 10);

                    $("#start-date").val(startDateValue);
                    $("#end-date").val(endDateValue);
                }

                showChart();
                loadPageViewAll();
                loadUserStatisticsWhenActive();
            }
        });

        function changeDay() {
            $("#selected-date").text("Custom");
            showChart();
            loadPageViewAll();
            loadUserStatisticsWhenActive();
        }

        showChart();
        function showChart() {

            var spaceKey = AJS.Meta.get("space-key");

            var start = $("#start-date").val();
            start = start === "" ? "" : new Date(start).toISOString().slice(0,10);

            var end = $("#end-date").val();
            end = end === "" ? "" : new Date(end).toISOString().slice(0,10);

            $.ajax({
                cache: false,
                data: {
                    startDate: start,
                    endDate: end,
                    spaceKey: spaceKey
                },
                dataType: "json",
                error: function (XMLHttpRequest, textStatus, errorThrown) {
                    $("#trend-chart #chart").html("Error rendering chart.");
                },
                success: function (data) {
                    try {
                        if (data.status === true) {

                            var showPoint = false;
                            if(data.result !== undefined && data.result.length === 1){
                                showPoint = true;
                            }

                            var keys = {
                                x: 'date',
                                value: ["blogs", "pages", "comments", "views"]
                            };

                            var names = {
                                blogs: "Blogs",
                                pages: "Pages",
                                comments: "Comments",
                                views: "Views"
                            };

                            var chart = c3.generate({
                                padding: {
                                    right: 20
                                },
                                bindto: '#trend-chart #chart',
                                data: {
                                    x: 'date',
                                    xFormat: '%Y-%m-%d',
                                    json: data.result,
                                    keys: keys,
                                    names: names,
                                    colors: {
                                        comments: '#ff7f0e',
                                        views: '#2ca02c',
                                        blogs:'#1f77b4',
                                        pages: '#d62728'
                                    }
                                },
                                axis: {
                                    x: {
                                        type: 'timeseries',
                                        tick: {
                                            //format : "%m/%d" // https://github.com/mbostock/d3/wiki/Time-Formatting#wiki-format
                                            //format: "%e %b %y" // https://github.com/mbostock/d3/wiki/Time-Formatting#wiki-format

                                            format: "%b %e, %y"
                                        }
                                    },
                                    y:{
                                        min : 0,
                                        padding: {top: 100, bottom: 0}
                                    }
                                },
                                point: {
                                    show: showPoint
                                }
                            });
                        }
                        else {
                            $("#trend-chart #chart").html("Error rendering chart.");
                        }
                    }catch (err){
                        $("#trend-chart #chart").html("Error rendering chart.");
                    }

                },
                type: "GET",
                timeout: PageTrackingUtils.ajaxTimeout,
                url: PageTrackingUtils.getPageUtilityServiceBaseUrl("/page-chart-statistics")
            });
        }


        $("#tab-users").on("click", function (e) {
            e.preventDefault();
            loadUserStatistics();
        });

        function loadUserStatisticsWhenActive() {
            if($("#tab-users").hasClass("active-tab")){
                loadUserStatistics();
            }
        }

        function loadUserStatistics(){

            try {
                // show loading icon
                $("#user-statistics #user-statistics-loading").show();
                var requestData = getPageViewSearchData();

                $("#user-statistics-export-link").attr("href", Confluence.getContextPath() +
                    "/rest/page-tracking-services/1.0/page-tracking/user-statistics.xlsx?startDate=" + requestData.startDate +
                    "&endDate=" + requestData.endDate + "&spaceKey=" + requestData.spaceKey);

                var pageLoadingEl = $("#page-loading img").show();

                $.ajax({
                    data: requestData,
                    cache: false,
                    dataType: "json",
                    error: function (XMLHttpRequest, textStatus, errorThrown) {
                        pageLoadingEl.hide();

                        if(XMLHttpRequest.status === 401) {
                            var redirectUrl = AJS.contextPath() + "/login.action?os_destination=" +
                                encodeURIComponent(window.location.href) + "&permissionViolation=true";
                            window.location.href = redirectUrl;
                        }

                    },
                    success: function (data) {
                        var result = "";
                        if (data.status === true) {
                            result = Elisoft.Confluence.PageView.Templates.userStatsView({ data: data });
                        }

                        $("#user-statistics table#user-statistics-result tbody").html(result);
                        pageLoadingEl.hide();

                        try{
                            AJS.Confluence.Binder.userHover();
                        }catch (err)
                        {}
                    },
                    type: "GET",
                    timeout: PageTrackingUtils.ajaxTimeout,
                    url: PageTrackingUtils.getPageUtilityServiceBaseUrl("/page-activity")
                });
            }catch (err){

            }
        }

    });
}(AJS.$));