(function($){
    $(function () {

        /* Initialize start date and end date */
        initializeDateSelectors();
        function initializeDateSelectors() {
            if($('#start-date').length > 0) {
                $('#start-date').datePicker({'overrideBrowserDefault': true, onSelect: changeDay});
                $('#end-date').datePicker({'overrideBrowserDefault': true, onSelect: changeDay});
            }

            var currentDate = new Date();
            var startDate = addDays(currentDate, -30);
            var startDateValue = (new Date(startDate - startDate.getTimezoneOffset() * 60000)).toISOString().slice(0, 10);
            var endDate = currentDate;
            var endDateValue = (new Date(endDate - endDate.getTimezoneOffset() * 60000)).toISOString().slice(0, 10);

            $("#start-date").val(startDateValue);
            $("#end-date").val(endDateValue);
        }

        $("#selected-date-dropdown a").on("click", function (e) {
            e.preventDefault();

            var text = $(this).text();
            $("#selected-date").text(text);

            var currentDate = new Date();
            var startDate = currentDate;
            var endDate = currentDate;

            if(text === "Past 30 days"){
                startDate = addDays(startDate, -30);

            }else if(text === "Past 90 days"){
                startDate = addDays(startDate, -90);

            }else if(text === "This month"){
                startDate = new Date(startDate.getFullYear(), startDate.getMonth(), 1);

            }else if(text === "Last month"){
                startDate = new Date(startDate.getFullYear(), startDate.getMonth()- 1, 1);
                endDate = new Date(endDate.getFullYear(), endDate.getMonth(), 0);

            }else if(text === "All dates"){
                $("#start-date").val("");
                $("#end-date").val("");
            }

            if(text !== "Custom"){

                if(text !== "All dates") {

                    var startDateValue = (new Date(startDate - startDate.getTimezoneOffset() * 60000)).toISOString().slice(0, 10);
                    var endDateValue = (new Date(endDate - endDate.getTimezoneOffset() * 60000)).toISOString().slice(0, 10);

                    $("#start-date").val(startDateValue);
                    $("#end-date").val(endDateValue);
                }

                searchStatistics();
                loadPageViewAll();
                loadUserStatisticsWhenActive();
            }
        });

        function addDays(date, days) {
            var result = new Date(date);
            result.setDate(result.getDate() + days);
            return result;
        }

        function changeDay() {
            $("#selected-date").text("Custom");
            searchStatistics();
            loadPageViewAll();
            loadUserStatisticsWhenActive();
        }

        /* Load page view all */

        function getPageViewSearchData() {
            var start = $("#start-date").val();
            start = start === "" ? "" : new Date(start).toISOString().slice(0, 10);

            var end = $("#end-date").val();
            end = end === "" ? "" : new Date(end).toISOString().slice(0, 10);

            var pageName = $("#page-stats-page").val();
            var spaceKey = $("#page-stats-space-key").val();

            if($("#page-stats-space").val().length === 0){
                spaceKey = "";
            }

            // Get sorKey and sortOrder
            var sortKey = "";
            var sortOrder = "";
            var sortItemElement = $("span.fa.fa-sort-desc", pageTrackingTableHead);
            if(sortItemElement.length > 0){
                sortOrder = "desc";
                sortKey = sortItemElement.attr("data-sort-key");
            }else {
                sortItemElement = $("span.fa.fa-sort-asc", pageTrackingTableHead);
                if (sortItemElement.length > 0) {
                    sortOrder = "asc";
                    sortKey = sortItemElement.attr("data-sort-key");
                }
            }

            return {
                startDate: start,
                endDate: end,
                sortKey: sortKey,
                sortOrder: sortOrder,
                keyword: pageName,
                spaceKey: spaceKey
            }
        }

        loadPageViewAll();
        function loadPageViewAll(currentPage){
            if(currentPage == null || currentPage == undefined){
                currentPage = 1;
            }

            try {
                // show loading icon
                $("#page-tracking #page-tracking-results #page-tracking-loading").show();

                var requestData = getPageViewSearchData();
                $.extend(requestData, {
                    pageIndex : currentPage
                });

                $("#page-view-export-link").attr("href", Confluence.getContextPath() +
                    "/rest/page-tracking-services/1.0/page-tracking/page-statistics.xlsx?startDate=" + requestData.startDate +
                    "&endDate=" + requestData.endDate + "&keyword=" + requestData.keyword + "&spaceKey=" + requestData.spaceKey);

                $.ajax({
                    data: requestData,
                    cache: false,
                    dataType: "json",
                    error: function (XMLHttpRequest, textStatus, errorThrown) {
                        $("#page-tracking #page-tracking-results #page-tracking-loading").hide();

                        if(XMLHttpRequest.status === 401) {
                            var redirectUrl = AJS.contextPath() + "/login.action?os_destination=" +
                                encodeURIComponent(window.location.href) + "&permissionViolation=true";
                            window.location.href = redirectUrl;
                        }

                    },
                    success: function (data) {
                        var result = "";
                        if (data.status === true) {
                            result = Elisoft.Confluence.PageView.Templates.pageView({ data: data });
                        }

                        $("#page-tracking #page-tracking-results table tbody").html(result);
                        $("#page-tracking #page-tracking-results #page-tracking-loading").hide();

                        var pagination = Elisoft.Confluence.PageView.Templates.pagination({ currentPage: currentPage, totalPages: data.totalPages });
                        $("#page-pagination").html(pagination);

                    },
                    type: "GET",
                    timeout: PageTrackingUtils.ajaxTimeout,
                    url: PageTrackingUtils.getPageUtilityServiceBaseUrl("/page-view-all")
                });
            }catch (err){

            }
        }

        var pagePagination = $("#page-pagination");
        pagePagination.on("click", "a", function(e) {
            e.preventDefault();

            var currentPage = parseInt($(this).attr("data-page"));
            loadPageViewAll(currentPage);
        });

        var pageTrackingTableHead = $("#page-tracking #page-tracking-results table thead");
        pageTrackingTableHead.on("click", "th", function(e) {
            e.preventDefault();

            var sortIcon = $("span.fa", this);
            if(sortIcon.length > 0){
                var classToAdd = "";
                if(!sortIcon.hasClass("fa-sort-asc") && !sortIcon.hasClass("fa-sort-desc")){
                    if(sortIcon.hasClass("down")){
                        classToAdd = "fa-sort-desc";
                    }
                    else {
                        classToAdd = "fa-sort-asc";
                    }
                }
                else if(sortIcon.hasClass("fa-sort-asc")){
                    sortIcon.addClass("down");
                    sortIcon.removeClass("fa-sort-asc")
                }
                else if(sortIcon.hasClass("fa-sort-desc")){
                    sortIcon.removeClass("down");
                    sortIcon.removeClass("fa-sort-desc");
                }

                $("th span.fa", pageTrackingTableHead).removeClass("fa-sort-desc").removeClass("fa-sort-asc");

                if(classToAdd != ""){
                    sortIcon.addClass(classToAdd);
                }

                var currentPage = parseInt($(".aui-nav-selected", pagePagination).text());
                if(isNaN(currentPage)){
                    currentPage = 1;
                }

                loadPageViewAll(currentPage);
            }
        });


        var pageStatsSpaceKey = $("input[name='page-stats-space-key']");
        var pageStatsSpace = $("input[name='page-stats-space']");

        pageStatsSpace.keypress(function(e) {
            if (e.which !== 13) {
                pageStatsSpaceKey.val(e.which);
            }
        });

        pageStatsSpace.bind("selected.autocomplete-content", function(e, selection) {
            pageStatsSpaceKey.val(selection.content.key);
            $(this).val(selection.content.name);
        });

        $("#page-stats-search").on("click", function (e) {
            e.preventDefault();
            loadPageViewAll();
        });

        $("#page-stats-page").keypress(function(e){
            var key = e.which;
            if(key === 13){
                loadPageViewAll();
            }
        });

        $("#page-stats-clear").on("click", function (e) {
            e.preventDefault();

            $("#page-stats-page").val("");
            $("#page-stats-space").val("");

            loadPageViewAll();
        });

        /*function showpageTrackingDialog(pageId){
            var loadingIcon = "<img src='" +
                Confluence.getContextPath() +
                '/download/resources/com.elitesoftsp.confluence.page.tracking.plugins:page-tracking-main-res/images/loading.gif'
                + "' >";

            AJS.dialog2("#page-tracking-dialog").show();

            loadPages();

            function loadPages() {

                var dialogBody = $("#page-tracking-dialog .page-tracking-dialog-content");

                var messageBox = $('.message-box', dialogBody);
                var loadingBox = $('.loading-box', dialogBody);
                var resultBox = $('.result-box', dialogBody);

                loadingBox.html(loadingIcon);

                $.ajax({
                    cache: false,
                    data: {pageId: pageId},
                    dataType: "json",
                    error: function (XMLHttpRequest, textStatus, errorThrown) {
                        if (XMLHttpRequest.status === 401) {
                            location.reload();
                        }
                    },
                    success: function (data) {

                        var result = "";
                        if (data.status == true && data.pages.length > 0) {

                            var pages = data.pages;
                            result += "<h4>" + PageTrackingUtils.escapeHtml(data.pageName) + "</h4>";
                            var exportLink = "<a class='aui-button' style='float: right' href='" + Confluence.getContextPath() + "/rest/page-tracking-services/1.0/page-tracking/page-viewers.xlsx?pageId=" + pageId + "'>Export</a>"
                            result +="<table class='aui'><thead><tr><th>#</th><th>Name</th><th>Views</th><th>Last viewed</th><th>" + exportLink + "</th></tr></thead><tbody>";

                            for(var i = 0; i < pages.length; i ++){
                                var row ="";
                                var userLink = pages[i].viewer;
                                if(pages[i].viewer != "Anonymous" && pages[i].viewer != "Authorized User") {
                                    userLink = "<a href='"
                                        + Confluence.getContextPath() + "/display/~" + pages[i].viewer +
                                        "' class='confluence-userlink' data-username='" + pages[i].viewer +
                                        "' target='_blank' >" + PageTrackingUtils.escapeHtml(pages[i].viewerFullName) + "</a>"
                                }

                                row += "<tr>";

                                row += "<td>" + (i + 1)  + "</td>";

                                row += "<td>" + userLink  + "</td>";

                                row += "<td>" + pages[i].timesViewed  + "</td>";

                                row += "<td>" + pages[i].lastViewed  + "</td>";

                                row += "<td>" + ""  + "</td>";

                                row+="</tr>";

                                result += row;
                            }

                            result +="</tbody></table>";
                        }

                        if(data.valid == false){
                            messageBox.html("<div class='aui-message aui-message-warning'><p>Page View requires a valid licence. Please ask your administrator(s) to create or update a licence.</p></div>");
                            resultBox.html("");
                            loadingBox.html("");
                            return;

                        }

                        loadingBox.html("");
                        resultBox.html(result).fadeIn("slow");

                        try{
                            AJS.Confluence.Binder.userHover();
                        }catch (err)
                        {}


                    },
                    type: "GET",
                    timeout: PageTrackingUtils.ajaxTimeout,
                    url: PageTrackingUtils.getPageUtilityServiceBaseUrl("/page-view")
                });
            };
        }*/

        // Hides the dialog
        AJS.$("#page-tracking-dialog-close-button").click(function(e) {
            e.preventDefault();
            AJS.dialog2("#page-tracking-dialog").hide();
        });

        var pageTrackingResults = $("#page-tracking-results");

        // view tracking detail
        /*pageTrackingResults.on("click", ".view-tracking-detail", function(e) {
            e.preventDefault();
            showpageTrackingDialog($(this).attr("data"));
        });*/

        var $deletePageViewDialog = $("#delete-page-view-dialog");
        // delete page view
        pageTrackingResults.on("click", ".delete-page-view", function(e) {
            e.preventDefault();

            AJS.dialog2($deletePageViewDialog).show();
            $("#page-view-page-id",$deletePageViewDialog).val($(this).attr("data"));
        });

        // Save
        $deletePageViewDialog.on("click", ".ok-button", function(event){
            event.preventDefault();

            var pageId = $("#page-view-page-id", $deletePageViewDialog).val();

            $.ajax({
                cache: false,
                data: {
                    pageId: pageId
                },
                dataType: "json",
                type: "PUT",
                error: function(jqXHR, textStatus, errorThrown) {

                    window.location.reload();
                },
                success: function(data) {
                    loadPageViewAll();
                    searchStatistics();
                    AJS.dialog2($deletePageViewDialog).hide();
                },
                timeout: PageTrackingUtils.ajaxTimeout,
                url: PageTrackingUtils.getPageUtilityServiceBaseUrl("/clear-page-view")
            });

        });

        // Cancel
        $deletePageViewDialog.on("click", ".cancel-button", function(event){
            event.preventDefault();

            AJS.dialog2($deletePageViewDialog).hide();
        });

        /* SPACE STATISTICS */

        searchStatistics();

        function searchStatistics(currentPage) {

            if(currentPage == null || currentPage == undefined){
                currentPage = 1;
            }

            try {

                var spaceName = $("#space-stats-space").val();

                var start = $("#start-date").val();
                start = start === "" ? "" : new Date(start).toISOString().slice(0, 10);

                var end = $("#end-date").val();
                end = end === "" ? "" : new Date(end).toISOString().slice(0, 10);

                $("#space-export-link").attr("href", Confluence.getContextPath() +
                        "/rest/page-tracking-services/1.0/page-tracking/space-statistics.xlsx?startDate=" + start +
                        "&endDate=" + end + "&keyword=" + spaceName);

                $("#page-statistics-detail #page-statistics-loading").show();

                // Get sorKey and sortOrder
                var sortKey = "";
                var sortOrder = "";
                var sortItemElement = $("span.fa.fa-sort-desc", spaceStatisticsTableHead);
                if(sortItemElement.length > 0){
                    sortOrder = "desc";
                    sortKey = sortItemElement.attr("data-sort-key");
                }else {
                    sortItemElement = $("span.fa.fa-sort-asc", spaceStatisticsTableHead);
                    if (sortItemElement.length > 0) {
                        sortOrder = "asc";
                        sortKey = sortItemElement.attr("data-sort-key");
                    }
                }

                $.ajax({
                    cache: false,
                    data: {
                        startDate: start,
                        endDate: end,
                        pageIndex : currentPage,
                        sortKey: sortKey,
                        sortOrder: sortOrder,
                        keyword: spaceName
                    },
                    dataType: "json",
                    error: function (XMLHttpRequest, textStatus, errorThrown) {

                        $("#page-statistics-detail #page-statistics-loading").hide();

                        if(XMLHttpRequest.status === 401) {
                            var redirectUrl = AJS.contextPath() + "/login.action?os_destination=" +
                                encodeURIComponent(window.location.href) + "&permissionViolation=true";
                            window.location.href = redirectUrl;
                        }
                    },
                    success: function (data) {

                        var spaceHtml = "";
                        var siteHtml = "";
                        if (data.status === true) {
                            spaceHtml = Elisoft.Confluence.PageView.Templates.spaceStatsView({ data: data });
                            siteHtml = Elisoft.Confluence.PageView.Templates.siteInfoView({ data: data });
                        }

                        var spaceStatisticsDetail = $("#page-statistics-detail");

                        $("#page-statistics-site #page-statistics-site-table tbody").html(siteHtml);
                        $("#page-statistics-space tbody", spaceStatisticsDetail).html(spaceHtml);
                        $("#page-statistics-loading", spaceStatisticsDetail).hide();

                        var pagination = Elisoft.Confluence.PageView.Templates.pagination({
                            currentPage: currentPage, totalPages: data.totalPages
                        });

                        $("#space-pagination").html(pagination);

                    },
                    type: "GET",
                    timeout: PageTrackingUtils.ajaxTimeout,
                    url: PageTrackingUtils.getPageUtilityServiceBaseUrl("/page-view-statistics")
                });
            }catch (err){}
        }

        var spacePagination = $("#space-pagination");
        spacePagination.on("click", "a", function(e) {
            e.preventDefault();
            $("#page-statistics-detail #page-statistics-loading").show();
            var currentPage = parseInt($(this).attr("data-page"));
            searchStatistics(currentPage);
        });

        var spaceStatisticsTableHead = $("#page-statistics-space thead");
        spaceStatisticsTableHead.on("click", "th", function(e) {
            e.preventDefault();

            var sortIcon = $("span.fa", this);
            if(sortIcon.length > 0){
                var classToAdd = "";
                if(!sortIcon.hasClass("fa-sort-asc") && !sortIcon.hasClass("fa-sort-desc")){
                    if(sortIcon.hasClass("down")){
                        classToAdd = "fa-sort-desc";
                    }
                    else {
                        classToAdd = "fa-sort-asc";
                    }
                }
                else if(sortIcon.hasClass("fa-sort-asc")){
                    sortIcon.addClass("down");
                    sortIcon.removeClass("fa-sort-asc")
                }
                else if(sortIcon.hasClass("fa-sort-desc")){
                    sortIcon.removeClass("down");
                    sortIcon.removeClass("fa-sort-desc");
                }

                $("th span.fa", spaceStatisticsTableHead).removeClass("fa-sort-desc").removeClass("fa-sort-asc");

                if(classToAdd != ""){
                    sortIcon.addClass(classToAdd);
                }

                $("#page-statistics-detail #page-statistics-loading").show();

                var currentPage = parseInt($(".aui-nav-selected", spacePagination).text());
                if(isNaN(currentPage)){
                    currentPage = 1;
                }

                searchStatistics(currentPage);
            }
        });

        $("#space-stats-search").on("click", function (e) {
            e.preventDefault();
            searchStatistics();
        });

        $("#space-stats-space").keypress(function(e){
            var key = e.which;
            if(key === 13){
                searchStatistics();
            }
        });

        $("#space-stats-clear").on("click", function (e) {
            e.preventDefault();
            $("#space-stats-space").val("");
            searchStatistics();
        });

        /*******************************************/
        /* USER STATISTICS */

        $("#tab-user-statistics").on("click", function (e) {
            e.preventDefault();
            loadUserStatistics();
        });

        function loadUserStatisticsWhenActive() {
            if($("#tab-user-statistics").hasClass("active-tab")){
                loadUserStatistics();
            }
        }

        function loadUserStatistics(){

            try {
                // show loading icon
                $("#user-statistics #user-statistics-loading").show();
                var requestData = getUserSearchData();


                $("#user-statistics-export-link").attr("href", Confluence.getContextPath() +
                    "/rest/page-tracking-services/1.0/page-tracking/user-statistics.xlsx?startDate=" + requestData.startDate +
                    "&endDate=" + requestData.endDate);

                $.ajax({
                    data: requestData,
                    cache: false,
                    dataType: "json",
                    error: function (XMLHttpRequest, textStatus, errorThrown) {
                        $("#user-statistics #user-statistics-loading").hide();

                        if(XMLHttpRequest.status === 401) {
                            var redirectUrl = AJS.contextPath() + "/login.action?os_destination=" +
                                encodeURIComponent(window.location.href) + "&permissionViolation=true";
                            window.location.href = redirectUrl;
                        }

                    },
                    success: function (data) {
                        var result = "";
                        if (data.status === true) {
                            result = Elisoft.Confluence.PageView.Templates.userStatsView({ data: data });
                        }

                        $("#tabs-user-statistics table#user-statistics-result tbody").html(result);
                        $("#user-statistics #user-statistics-loading").hide();

                        try{
                            AJS.Confluence.Binder.userHover();
                        }catch (err)
                        {}

                    },
                    type: "GET",
                    timeout: PageTrackingUtils.ajaxTimeout,
                    url: PageTrackingUtils.getPageUtilityServiceBaseUrl("/page-activity")
                });
            }catch (err){

            }
        }

        function getUserSearchData() {
            var start = $("#start-date").val();
            start = start === "" ? "" : new Date(start).toISOString().slice(0, 10);

            var end = $("#end-date").val();
            end = end === "" ? "" : new Date(end).toISOString().slice(0, 10);

            // Get sorKey and sortOrder
            var sortKey = "";
            var sortOrder = "";
            var sortItemElement = $("span.fa.fa-sort-desc", pageTrackingTableHead);
            if(sortItemElement.length > 0){
                sortOrder = "desc";
                sortKey = sortItemElement.attr("data-sort-key");
            }else {
                sortItemElement = $("span.fa.fa-sort-asc", pageTrackingTableHead);
                if (sortItemElement.length > 0) {
                    sortOrder = "asc";
                    sortKey = sortItemElement.attr("data-sort-key");
                }
            }

            return {
                startDate: start,
                endDate: end,
                sortKey: sortKey,
                sortOrder: sortOrder
            }
        }

        $("#update-user-statistics").on("click", function (e) {

            e.preventDefault();

            $("#user-statistics #user-statistics-loading").show();

            $.ajax({
                cache: false,
                data: {},
                dataType: "json",
                type: "PUT",
                error: function(jqXHR, textStatus, errorThrown) {
                    window.location.reload();
                },
                success: function(data) {
                    loadUserStatistics();
                },
                timeout: PageTrackingUtils.ajaxTimeout,
                url: PageTrackingUtils.getPageUtilityServiceBaseUrl("/user-statistics")
            });

        });

        /* ------------------------------------- */

        function showChart(spaceKey, spaceName, pageId, pageName) {
            AJS.dialog2("#stats-trends-dialog").show();

            $("#stats-trends-dialog #chart").html("");

            var infor = spaceName == '' ? pageName : spaceName;
            $("#space-infor").html(infor);

            var start = $("#start-date").val();
            start = start === "" ? "" : new Date(start).toISOString().slice(0,10);

            var end = $("#end-date").val();
            end = end === "" ? "" : new Date(end).toISOString().slice(0,10);

            $.ajax({
                cache: false,
                data: {
                    startDate: start,
                    endDate: end,
                    spaceKey: spaceKey,
                    pageId: pageId
                },
                dataType: "json",
                error: function (XMLHttpRequest, textStatus, errorThrown) {
                    $("#space-infor").html("Error rendering chart.");
                    $("#stats-trends-dialog #chart").html("");
                },
                success: function (data) {
                    try {
                        if (data.status === true) {

                            var showPoint = false;
                            if(data.result !== undefined && data.result.length === 1){
                                showPoint = true;
                            }

                            var keys = {
                                x: 'date',
                                value: ["blogs", "pages", "comments", "views"]
                            };

                            var names = {
                                blogs: "Blogs",
                                pages: "Pages",
                                comments: "Comments",
                                views: "Views"
                            };

                            if(pageId != undefined && pageId > 0){
                                keys = {
                                    x: 'date',
                                    value: ["comments", "views"]
                                };
                                names = {
                                    comments: "Comments", views: "Views"
                                };
                            }

                            var chart = c3.generate({
                                padding: {
                                    right: 20
                                },
                                bindto: '#stats-trends-dialog #chart',
                                data: {
                                    x: 'date',
                                    xFormat: '%Y-%m-%d',
                                    json: data.result,
                                    keys: keys,
                                    names: names,
                                    colors: {
                                        comments: '#ff7f0e',
                                        views: '#2ca02c',
                                        blogs:'#1f77b4',
                                        pages: '#d62728'
                                    }
                                },
                                axis: {
                                    x: {
                                        type: 'timeseries',
                                        tick: {
                                            //format : "%m/%d" // https://github.com/mbostock/d3/wiki/Time-Formatting#wiki-format
                                            //format: "%e %b %y" // https://github.com/mbostock/d3/wiki/Time-Formatting#wiki-format

                                            format: "%b %e, %y"
                                        }
                                    },
                                    y:{
                                        min : 0,
                                        padding: {top: 100, bottom: 0}
                                    }
                                },
                                point: {
                                    show: showPoint
                                }
                            });
                        }
                        else {
                            $("#space-infor").html("Error rendering chart.");
                            $("#stats-trends-dialog #chart").html("");
                        }
                    }catch (err){
                        $("#space-infor").html("Error rendering chart.");
                        $("#stats-trends-dialog #chart").html("");
                    }

                },
                type: "GET",
                timeout: PageTrackingUtils.ajaxTimeout,
                url: PageTrackingUtils.getPageUtilityServiceBaseUrl("/page-chart-statistics")
            });
        }

        // show chart for SPACE
        var statsSpace = $("#page-statistics-space");
        statsSpace.on("click", ".stats-trends", function(event){
            event.preventDefault();
            var spaceKey = $(this).attr("data-space-key");
            var spaceName = $(this).attr("data-space-name");

            showChart(spaceKey, spaceName);

        });

        // show chart for PAGE
        /*var statsPage = $("#page-tracking #page-tracking-results");
        statsPage.on("click", ".stats-trends", function(event){
            event.preventDefault();
            var pageId = $(this).attr("data-page-id");
            var pageName = $(this).attr("data-page-name");

            showChart('', '', pageId, pageName);

        });*/

        // Hides the dialog
        AJS.$("#stats-trends-dialog-close-button").click(function(e) {
            e.preventDefault();
            AJS.dialog2("#stats-trends-dialog").hide();
        });


        // DELETE SPACE VIEW

        var $deleteSpaceViewDialog = $("#delete-space-view-dialog");
        // delete space view
        statsSpace.on("click", ".delete-space-view", function(e) {
            e.preventDefault();

            AJS.dialog2($deleteSpaceViewDialog).show();
            $("#space-view-space-key", $deleteSpaceViewDialog).val($(this).attr("data"));
        });

        // Save
        $deleteSpaceViewDialog.on("click", ".ok-button", function(event){
            event.preventDefault();

            var spaceKey = $("#space-view-space-key", $deleteSpaceViewDialog).val();

            $.ajax({
                cache: false,
                data: {
                    spaceKey: spaceKey
                },
                dataType: "json",
                type: "PUT",
                error: function(jqXHR, textStatus, errorThrown) {
                    window.location.reload();
                },
                success: function(data) {
                    loadPageViewAll();
                    searchStatistics();
                    AJS.dialog2($deleteSpaceViewDialog).hide();
                },
                timeout: PageTrackingUtils.ajaxTimeout,
                url: PageTrackingUtils.getPageUtilityServiceBaseUrl("/clear-space-view")
            });

        });

        // Cancel
        $deleteSpaceViewDialog.on("click", ".cancel-button", function(event){
            event.preventDefault();

            AJS.dialog2($deleteSpaceViewDialog).hide();
        });

    });
}(AJS.$));