(function($){
    $(function () {

        /* Initialize start date and end date */
        if($('#start-date').length > 0) {
            $('#start-date').datePicker({'overrideBrowserDefault': true, onSelect: changeDay});
            $('#end-date').datePicker({'overrideBrowserDefault': true, onSelect: changeDay});
        }

        $("#selected-date-dropdown a").on("click", function (e) {
            e.preventDefault();

            var text = $(this).text();
            $("#selected-date").text(text);

            var currentDate = new Date();
            var startDate = currentDate;
            var endDate = currentDate;

            if(text === "Past 30 days"){
                startDate = addDays(startDate, -30);

            }else if(text === "Past 90 days"){
                startDate = addDays(startDate, -90);

            }else if(text === "This month"){
                startDate = new Date(startDate.getFullYear(), startDate.getMonth(), 1);

            }else if(text === "Last month"){
                startDate = new Date(startDate.getFullYear(), startDate.getMonth()- 1, 1);
                endDate = new Date(endDate.getFullYear(), endDate.getMonth(), 0);

            }else if(text === "All dates"){
                $("#start-date").val("");
                $("#end-date").val("");
            }

            if(text !== "Custom"){
                if(text !== "All dates") {
                    var startDateValue = (new Date(startDate - startDate.getTimezoneOffset() * 60000)).toISOString().slice(0, 10);
                    var endDateValue = (new Date(endDate - endDate.getTimezoneOffset() * 60000)).toISOString().slice(0, 10);

                    $("#start-date").val(startDateValue);
                    $("#end-date").val(endDateValue);
                }

                showChart();
            }
        });

        var currentDate = new Date();
        var startDate = addDays(currentDate, -30);
        var startDateValue = (new Date(startDate - startDate.getTimezoneOffset() * 60000)).toISOString().slice(0, 10);
        var endDate = currentDate;
        var endDateValue = (new Date(endDate - endDate.getTimezoneOffset() * 60000)).toISOString().slice(0, 10);

        $("#start-date").val(startDateValue);
        $("#end-date").val(endDateValue);

        function addDays(date, days) {
            var result = new Date(date);
            result.setDate(result.getDate() + days);
            return result;
        }

        function changeDay() {
            $("#selected-date").text("Custom");
            showChart();
        }

        showChart();
        function showChart() {

            var pageId = $('#page-id').val();
            $("#trend-chart #chart").html("");

            var start = $("#start-date").val();
            start = start === "" ? "" : new Date(start).toISOString().slice(0,10);

            var end = $("#end-date").val();
            end = end === "" ? "" : new Date(end).toISOString().slice(0,10);

            $.ajax({
                cache: false,
                data: {
                    startDate: start,
                    endDate: end,
                    pageId: pageId
                },
                dataType: "json",
                error: function (XMLHttpRequest, textStatus, errorThrown) {
                    $("#trend-chart #chart").html("Error rendering chart.");
                },
                success: function (data) {
                    try {
                        if (data.status === true) {

                            var keys = {
                                x: 'date',
                                value: ["comments", "views"]
                            };

                            var names = {
                                comments: "Comments", views: "Views"
                            };

                            var chart = c3.generate({
                                padding: {
                                    right: 20
                                },
                                bindto: '#trend-chart #chart',
                                data: {
                                    x: 'date',
                                    xFormat: '%Y-%m-%d',
                                    json: data.result,
                                    keys: keys,
                                    names: names
                                },
                                axis: {
                                    x: {
                                        type: 'timeseries',
                                        tick: {
                                            format: "%b %e, %y"
                                        }
                                    },
                                    y:{
                                        min : 0,
                                        padding: {top: 100, bottom: 0}
                                    }
                                }
                            });
                        }
                        else {
                            $("#trend-chart #chart").html("Error rendering chart.");
                        }
                    }catch (err){
                        $("#trend-chart #chart").html("Error rendering chart.");
                    }
                },
                type: "GET",
                timeout: PageTrackingUtils.ajaxTimeout,
                url: PageTrackingUtils.getPageUtilityServiceBaseUrl("/page-chart-statistics")
            });
        }
    });
}(AJS.$));